pub struct AccountUpdateRequest {Show 21 fields
pub account_subtype: Option<String>,
pub account_type: Option<String>,
pub apr: Option<f64>,
pub apy: Option<f64>,
pub available_balance: Option<f64>,
pub balance: Option<f64>,
pub cash_surrender_value: Option<f64>,
pub credit_limit: Option<f64>,
pub currency_code: Option<String>,
pub death_benefit: Option<i64>,
pub interest_rate: Option<f64>,
pub is_business: Option<bool>,
pub is_closed: Option<bool>,
pub is_hidden: Option<bool>,
pub loan_amount: Option<f64>,
pub metadata: Option<String>,
pub name: Option<String>,
pub nickname: Option<String>,
pub original_balance: Option<f64>,
pub property_type: Option<String>,
pub skip_webhook: Option<bool>,
}Expand description
AccountUpdateRequest
JSON schema
{
"type": "object",
"properties": {
"account_subtype": {
"description": "Can only be updated for manual accounts.",
"examples": [
"PERSONAL"
],
"type": "string"
},
"account_type": {
"description": "Can only be updated for manual accounts.",
"examples": [
"SAVINGS"
],
"type": "string"
},
"apr": {
"description": "Can only be updated for manual accounts.",
"examples": [
1
],
"type": "number"
},
"apy": {
"description": "Can only be updated for manual accounts.",
"examples": [
1
],
"type": "number"
},
"available_balance": {
"description": "Can only be updated for manual accounts.",
"examples": [
1000
],
"type": "number"
},
"balance": {
"description": "Can only be updated for manual accounts.",
"examples": [
1000
],
"type": "number"
},
"cash_surrender_value": {
"description": "Can only be updated for manual accounts.",
"examples": [
1000
],
"type": "number"
},
"credit_limit": {
"description": "Can only be updated for manual accounts.",
"examples": [
100
],
"type": "number"
},
"currency_code": {
"description": "Can only be updated for manual accounts.",
"examples": [
"USD"
],
"type": "string"
},
"death_benefit": {
"description": "Can only be updated for manual accounts.",
"examples": [
1000
],
"type": "integer"
},
"interest_rate": {
"description": "Can only be updated for manual accounts.",
"examples": [
1
],
"type": "number"
},
"is_business": {
"description": "Can be updated for manual accounts and aggregated
accounts.",
"examples": [
false
],
"type": "boolean"
},
"is_closed": {
"description": "Can only be updated for manual accounts.",
"examples": [
false
],
"type": "boolean"
},
"is_hidden": {
"description": "Can be updated for manual accounts and aggregated
accounts.",
"examples": [
false
],
"type": "boolean"
},
"loan_amount": {
"description": "Can only be updated for manual accounts.",
"examples": [
1000
],
"type": "number"
},
"metadata": {
"description": "Can only be updated for manual accounts.",
"examples": [
"some metadata"
],
"type": "string"
},
"name": {
"description": "Can only be updated for manual accounts.",
"examples": [
"Test account 2"
],
"type": "string"
},
"nickname": {
"description": "Can only be updated for manual accounts.",
"examples": [
"Swiss Account"
],
"type": "string"
},
"original_balance": {
"description": "Can only be updated for manual accounts.",
"examples": [
10
],
"type": "number"
},
"property_type": {
"description": "Can only be updated for manual accounts.",
"examples": [
"VEHICLE"
],
"type": "string"
},
"skip_webhook": {
"description": "If set to true, prevents sending an account webhook
for the update if that webhook type is enabled for you.",
"examples": [
true
],
"type": "boolean"
}
}
}Fields
account_subtype: Option<String>Can only be updated for manual accounts.
account_type: Option<String>Can only be updated for manual accounts.
apr: Option<f64>apy: Option<f64>available_balance: Option<f64>balance: Option<f64>cash_surrender_value: Option<f64>credit_limit: Option<f64>currency_code: Option<String>Can only be updated for manual accounts.
death_benefit: Option<i64>Can only be updated for manual accounts.
interest_rate: Option<f64>is_business: Option<bool>Can be updated for manual accounts and aggregated accounts.
is_closed: Option<bool>Can only be updated for manual accounts.
Can be updated for manual accounts and aggregated accounts.
loan_amount: Option<f64>metadata: Option<String>Can only be updated for manual accounts.
name: Option<String>Can only be updated for manual accounts.
nickname: Option<String>Can only be updated for manual accounts.
original_balance: Option<f64>property_type: Option<String>Can only be updated for manual accounts.
skip_webhook: Option<bool>If set to true, prevents sending an account webhook for the update if that webhook type is enabled for you.