pub struct BudgetCreateRequest {
pub amount: Option<i64>,
pub category_guid: String,
pub metadata: Option<String>,
pub parent_guid: String,
pub skip_webhook: Option<bool>,
}Expand description
BudgetCreateRequest
JSON schema
{
"type": "object",
"required": [
"category_guid",
"parent_guid"
],
"properties": {
"amount": {
"description": "Amount of the budget.",
"examples": [
1000
],
"type": "integer"
},
"category_guid": {
"description": "Unique identifier of the category.",
"examples": [
"CAT-bd56d35a-a9a7-6e10-66c1-5b9cc1b6c81a"
],
"type": "string"
},
"metadata": {
"description": "Additional information a partner can store on the
budget.",
"examples": [
"Additional information"
],
"type": "string"
},
"parent_guid": {
"description": "Unique identifier of the parent budget. This is
only required when creating a budget on a sub-category.",
"examples": [
"BGT-6be44a91-e105-f68a-4770-8c7c0a5c9778"
],
"type": "string"
},
"skip_webhook": {
"description": "When set to true, this parameter will prevent a
webhook from being triggered by the request.",
"examples": [
true
],
"type": "boolean"
}
}
}Fields
amount: Option<i64>Amount of the budget.
category_guid: StringUnique identifier of the category.
metadata: Option<String>Additional information a partner can store on the budget.
parent_guid: StringUnique identifier of the parent budget. This is only required when creating a budget on a sub-category.
skip_webhook: Option<bool>When set to true, this parameter will prevent a webhook from being triggered by the request.