BudgetResponse

Struct BudgetResponse 

pub struct BudgetResponse {
Show 16 fields pub amount: Option<f64>, pub category_guid: Option<String>, pub created_at: Option<String>, pub guid: Option<String>, pub is_exceeded: Option<bool>, pub is_off_track: Option<bool>, pub metadata: Option<String>, pub name: Option<String>, pub off_track_percentage: Option<f64>, pub parent_guid: Option<String>, pub percent_spent: Option<f64>, pub projected_spending: Option<f64>, pub revision: Option<i64>, pub transaction_total: Option<Value>, pub updated_at: Option<Value>, pub user_guid: Option<Value>,
}
BudgetResponse

JSON schema
{
 "properties": {
   "amount": {
     "description": "A goal amount set by the user for a category's
transaction total during a month.",
     "examples": [
       153
     ],
     "type": "number"
   },
   "category_guid": {
     "description": "Unique identifier for the budget category. Defined
by MX.",
     "examples": [
       "CAT-bd56d35a-a9a7-6e10-66c1-5b9cc1b6c81a"
     ],
     "type": "string"
   },
   "created_at": {
     "description": "Date and time the budget was created, represented
in ISO 8601 format with timestamp.",
     "examples": [
       "2018-10-18T19:51:26+00:00"
     ],
     "type": "string"
   },
   "guid": {
     "description": "Unique identifier for the budget. Defined by MX.",
     "examples": [
       "BGT-6ca0e3ef-c65e-4655-8b5a-275a3c19c21d"
     ],
     "type": "string"
   },
   "is_exceeded": {
     "description": "If the budget has been exceeded, this field will be
true. Otherwise, this field will be false.",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "is_off_track": {
     "description": "If the budget is off track, this field will be
true. Otherwise, this field will be false.",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "metadata": {
     "description": "Additional information a partner can store on the
budget.",
     "examples": [
       "some metadata"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "name": {
     "description": "The name of the budget that is visible to the user
(ie \"Food\", \"Bills\", \"Entertainment\", etc).",
     "examples": [
       "Food & Dining"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "off_track_percentage": {
     "description": "The percentage amount of off track spending.
(Deprecated).",
     "type": [
       "number",
       "null"
     ]
   },
   "parent_guid": {
     "description": "Unique identifier for the parent budget. Defined by
MX.",
     "type": [
       "string",
       "null"
     ]
   },
   "percent_spent": {
     "description": "The percentage of a budget that has been spent
during the current calendar month Calculated as the transaction total
divided by the amount and then multiplied by 100.A value of zero will be
returned when `amount` is zero.",
     "examples": [
       1276.34
     ],
     "type": [
       "number",
       "null"
     ]
   },
   "projected_spending": {
     "description": "The projected amount of spending for the budget.",
     "examples": [
       3562.4
     ],
     "type": "number"
   },
   "revision": {
     "description": "The revision number of this budget record.",
     "examples": [
       561
     ],
     "type": "integer"
   },
   "transaction_total": {
     "description": "The cumulative amount of all transactions under the
budget.",
     "examples": [
       1952.8
     ]
   },
   "updated_at": {
     "description": "Date and time the budget was updated, represented
in ISO 8601 format with timestamp.",
     "examples": [
       "2022-06-14T21:17:11+00:00"
     ]
   },
   "user_guid": {
     "description": "Unique identifier for the user. Defined by MX.",
     "examples": [
       "USR-11141024-90b3-1bce-cac9-c06ced52ab4c"
     ]
   }
 }
}

Fields

amount: Option<f64>category_guid: Option<String>

Unique identifier for the budget category. Defined by MX.

created_at: Option<String>

Date and time the budget was created, represented in ISO 8601 format with timestamp.

guid: Option<String>

Unique identifier for the budget. Defined by MX.

is_exceeded: Option<bool>

If the budget has been exceeded, this field will be true. Otherwise, this field will be false.

is_off_track: Option<bool>

If the budget is off track, this field will be true. Otherwise, this field will be false.

metadata: Option<String>

Additional information a partner can store on the budget.

name: Option<String>

The name of the budget that is visible to the user (ie “Food”, “Bills”, “Entertainment”, etc).

off_track_percentage: Option<f64>

The percentage amount of off track spending. (Deprecated).

parent_guid: Option<String>

Unique identifier for the parent budget. Defined by MX.

percent_spent: Option<f64>

The percentage of a budget that has been spent during the current calendar month Calculated as the transaction total divided by the amount and then multiplied by 100.A value of zero will be returned when amount is zero.

projected_spending: Option<f64>revision: Option<i64>

The revision number of this budget record.

transaction_total: Option<Value>

The cumulative amount of all transactions under the budget.

updated_at: Option<Value>

Date and time the budget was updated, represented in ISO 8601 format with timestamp.

user_guid: Option<Value>

Unique identifier for the user. Defined by MX.