ConnectWidgetRequest

Struct ConnectWidgetRequest 

pub struct ConnectWidgetRequest {
Show 15 fields pub client_redirect_url: Option<String>, pub color_scheme: Option<String>, pub current_institution_code: Option<String>, pub current_member_guid: Option<String>, pub disable_background_agg: Option<bool>, pub disable_institution_search: Option<bool>, pub enable_app2app: Option<bool>, pub include_identity: Option<bool>, pub include_transactions: Option<bool>, pub is_mobile_webview: Option<bool>, pub mode: Option<String>, pub oauth_referral_source: Option<String>, pub ui_message_version: Option<i64>, pub ui_message_webview_url_scheme: Option<String>, pub update_credentials: Option<bool>,
}
ConnectWidgetRequest

JSON schema
{
 "type": "object",
 "properties": {
   "client_redirect_url": {
     "examples": [
       "https://{yoursite.com}"
     ],
     "type": "string"
   },
   "color_scheme": {
     "examples": [
       "light"
     ],
     "type": "string"
   },
   "current_institution_code": {
     "examples": [
       "mxbank"
     ],
     "type": "string"
   },
   "current_member_guid": {
     "examples": [
       "MBR-7c6f361b-e582-15b6-60c0-358f12466b4b"
     ],
     "type": "string"
   },
   "disable_background_agg": {
     "examples": [
       false
     ],
     "type": "boolean"
   },
   "disable_institution_search": {
     "examples": [
       false
     ],
     "type": "boolean"
   },
   "enable_app2app": {
     "description": "This indicates whether OAuth app2app behavior is
enabled for institutions that support it. Defaults to `true`. When set
to `false`, the widget will **not** direct the end user to the
institution's mobile application. This setting is not persistent. This
setting currently only affects Chase institutions.\n",
     "examples": [
       false
     ],
     "type": "boolean"
   },
   "include_identity": {
     "examples": [
       false
     ],
     "type": "boolean"
   },
   "include_transactions": {
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "is_mobile_webview": {
     "examples": [
       false
     ],
     "type": "boolean"
   },
   "mode": {
     "examples": [
       "aggregation"
     ],
     "type": "string"
   },
   "oauth_referral_source": {
     "examples": [
       "BROWSER"
     ],
     "type": "string"
   },
   "ui_message_version": {
     "examples": [
       4
     ],
     "type": "integer"
   },
   "ui_message_webview_url_scheme": {
     "type": "string"
   },
   "update_credentials": {
     "examples": [
       false
     ],
     "type": "boolean"
   }
 }
}

Fields

client_redirect_url: Option<String>color_scheme: Option<String>current_institution_code: Option<String>current_member_guid: Option<String>disable_background_agg: Option<bool>disable_institution_search: Option<bool>enable_app2app: Option<bool>

This indicates whether OAuth app2app behavior is enabled for institutions that support it. Defaults to true. When set to false, the widget will not direct the end user to the institution’s mobile application. This setting is not persistent. This setting currently only affects Chase institutions.

include_identity: Option<bool>include_transactions: Option<bool>is_mobile_webview: Option<bool>mode: Option<String>oauth_referral_source: Option<String>ui_message_version: Option<i64>ui_message_webview_url_scheme: Option<String>update_credentials: Option<bool>