pub struct GoalRequest {
pub account_guid: String,
pub amount: f64,
pub completed_at: Option<String>,
pub goal_type_name: String,
pub has_been_spent: Option<bool>,
pub is_complete: Option<bool>,
pub meta_type_name: String,
pub metadata: Option<String>,
pub name: String,
pub position: Option<i64>,
pub targeted_to_complete_at: Option<String>,
}Expand description
GoalRequest
JSON schema
{
"type": "object",
"required": [
"account_guid",
"amount",
"goal_type_name",
"meta_type_name",
"name"
],
"properties": {
"account_guid": {
"description": "Unique identifier of the account for the goal.",
"examples": [
"ACT-4e431124-4a29-abf9-f059-ab232ac14dbf"
],
"type": "string"
},
"amount": {
"description": "Amount of the goal.",
"examples": [
4500.5
],
"type": "number"
},
"completed_at": {
"description": "Date and time the goal was completed.",
"examples": [
"2015-06-19T10:37:04-06:00"
],
"type": "string"
},
"goal_type_name": {
"description": "The goal type.",
"examples": [
"PAYOFF"
],
"type": "string"
},
"has_been_spent": {
"description": "Determines if the goal has been spent.",
"examples": [
false
],
"type": "boolean"
},
"is_complete": {
"description": "Determines if the goal is complete.",
"examples": [
false
],
"type": "boolean"
},
"meta_type_name": {
"description": "The category of the goal.",
"examples": [
"VACATION"
],
"type": "string"
},
"metadata": {
"description": "Additional information a partner can store on the
goal.",
"examples": [
"Additional information"
],
"type": "string"
},
"name": {
"description": "The name of the goal.",
"examples": [
"Save for Europe"
],
"type": "string"
},
"position": {
"description": "The priority of the goal in relation to multiple
goals.",
"examples": [
3
],
"type": "integer"
},
"targeted_to_complete_at": {
"description": "Date and time the goal is to complete. Intended for
users to set their own goal completion dates.",
"examples": [
"2026-12-08 00:00:00.000000"
],
"type": "string"
}
}
}Fields
account_guid: StringUnique identifier of the account for the goal.
amount: f64completed_at: Option<String>Date and time the goal was completed.
goal_type_name: StringThe goal type.
has_been_spent: Option<bool>Determines if the goal has been spent.
is_complete: Option<bool>Determines if the goal is complete.
meta_type_name: StringThe category of the goal.
metadata: Option<String>Additional information a partner can store on the goal.
name: StringThe name of the goal.
position: Option<i64>The priority of the goal in relation to multiple goals.
targeted_to_complete_at: Option<String>Date and time the goal is to complete. Intended for users to set their own goal completion dates.