pub struct GoalsResponse {Show 16 fields
pub account_guid: Option<String>,
pub amount: Option<f64>,
pub completed_at: Option<String>,
pub current_amount: Option<f64>,
pub goal_type_name: Option<String>,
pub guid: Option<String>,
pub has_been_spent: Option<bool>,
pub is_complete: Option<bool>,
pub meta_type_name: Option<String>,
pub metadata: Option<String>,
pub name: Option<String>,
pub position: Option<i64>,
pub projected_to_complete_at: Option<String>,
pub targeted_to_complete_at: Option<String>,
pub track_type_name: Option<String>,
pub user_guid: Option<String>,
}Expand description
GoalsResponse
JSON schema
{
"properties": {
"account_guid": {
"description": "Unique identifier of the account for the goal.",
"examples": [
"ACT-4e431124-4a29-abf9-f059-ab232ac14dbf"
],
"type": "string"
},
"amount": {
"description": "Amount of the goal.",
"examples": [
4500
],
"type": "number"
},
"completed_at": {
"description": "Date and time the goal was completed.",
"examples": [
"2015-06-19T10:37:04-06:00"
],
"type": "string"
},
"current_amount": {
"description": "The current amount of the goal.",
"examples": [
1651.27
],
"type": "number"
},
"goal_type_name": {
"description": "The goal type.",
"examples": [
"PAYOFF"
],
"type": "string"
},
"guid": {
"description": "The unique identifier for the goal. Defined by
MX.",
"examples": [
"GOL-524ca5db-a2d5-44f3-b048-16de16059024"
],
"type": "string"
},
"has_been_spent": {
"description": "Determines if the goal has been spent.",
"examples": [
false
],
"type": "boolean"
},
"is_complete": {
"description": "Determines if the goal is complete.",
"examples": [
false
],
"type": "boolean"
},
"meta_type_name": {
"description": "The category of the goal.",
"examples": [
"VACATION"
],
"type": "string"
},
"metadata": {
"description": "Additional information a partner can store on the
goal.",
"examples": [
"Additional information"
],
"type": "string"
},
"name": {
"description": "The name of the goal.",
"examples": [
"Save for Europe"
],
"type": "string"
},
"position": {
"description": "The priority of the goal in relation to multiple
goals.",
"examples": [
3
],
"type": "integer"
},
"projected_to_complete_at": {
"description": "The date on which the project was completed.",
"examples": [
"2022-06-14T16:03:53-00:00"
],
"type": "string"
},
"targeted_to_complete_at": {
"examples": [
"2026-12-08 00:00:00.000000"
],
"type": "string"
},
"track_type_name": {
"examples": [
"Track Type Name"
],
"type": "string"
},
"user_guid": {
"description": "The unique identifier for the the user. Defined by
MX.",
"examples": [
"USR-11141024-90b3-1bce-cac9-c06ced52ab4c"
],
"type": "string"
}
}
}Fields
account_guid: Option<String>Unique identifier of the account for the goal.
amount: Option<f64>completed_at: Option<String>Date and time the goal was completed.
current_amount: Option<f64>goal_type_name: Option<String>The goal type.
guid: Option<String>The unique identifier for the goal. Defined by MX.
has_been_spent: Option<bool>Determines if the goal has been spent.
is_complete: Option<bool>Determines if the goal is complete.
meta_type_name: Option<String>The category of the goal.
metadata: Option<String>Additional information a partner can store on the goal.
name: Option<String>The name of the goal.
position: Option<i64>The priority of the goal in relation to multiple goals.
projected_to_complete_at: Option<String>The date on which the project was completed.
targeted_to_complete_at: Option<String>track_type_name: Option<String>user_guid: Option<String>The unique identifier for the the user. Defined by MX.