MemberResponse

Struct MemberResponse 

pub struct MemberResponse {
Show 23 fields pub aggregated_at: Option<String>, pub background_aggregation_is_disabled: Option<bool>, pub connection_status: Option<String>, pub connection_status_message: Option<String>, pub guid: Option<String>, pub id: Option<String>, pub institution_code: Option<String>, pub institution_guid: Option<String>, pub is_being_aggregated: Option<bool>, pub is_managed_by_user: Option<bool>, pub is_manual: Option<bool>, pub is_oauth: Option<bool>, pub metadata: Option<String>, pub most_recent_job_detail_code: Option<i64>, pub most_recent_job_detail_text: Option<bool>, pub most_recent_job_guid: Option<bool>, pub name: Option<String>, pub needs_updated_credentials: Option<bool>, pub oauth_window_uri: Option<String>, pub successfully_aggregated_at: Option<String>, pub use_cases: Vec<MemberResponseUseCasesItem>, pub user_guid: Option<String>, pub user_id: Option<String>,
}
MemberResponse

JSON schema
{
 "type": "object",
 "properties": {
   "aggregated_at": {
     "examples": [
       "2016-10-13T18:07:57.000Z"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "background_aggregation_is_disabled": {
     "examples": [
       false
     ],
     "type": "boolean"
   },
   "connection_status": {
     "examples": [
       "CONNECTED"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "connection_status_message": {
     "examples": [
       "Connected to MX Bank"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "guid": {
     "examples": [
       "MBR-7c6f361b-e582-15b6-60c0-358f12466b4b"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "id": {
     "examples": [
       "unique_id"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "institution_code": {
     "examples": [
       "mxbank"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "institution_guid": {
     "examples": [
       "INST-12345678-90ab-cdef-1234-567890abcdef"
     ],
     "type": "string"
   },
   "is_being_aggregated": {
     "examples": [
       false
     ],
     "type": [
       "boolean",
       "null"
     ]
   },
   "is_managed_by_user": {
     "examples": [
       false
     ],
     "type": [
       "boolean",
       "null"
     ]
   },
   "is_manual": {
     "examples": [
       false
     ],
     "type": [
       "boolean",
       "null"
     ]
   },
   "is_oauth": {
     "examples": [
       false
     ],
     "type": [
       "boolean",
       "null"
     ]
   },
   "metadata": {
     "examples": [
       "\\\"credentials_last_refreshed_at\\\": \\\"2015-10-15\\"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "most_recent_job_detail_code": {
     "type": [
       "integer",
       "null"
     ]
   },
   "most_recent_job_detail_text": {
     "type": [
       "boolean",
       "null"
     ]
   },
   "most_recent_job_guid": {
     "examples": [
       "JOB-12345678-90ab-cdef-1234-567890abcdef"
     ],
     "type": [
       "boolean",
       "null"
     ]
   },
   "name": {
     "examples": [
       "MX Bank"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "needs_updated_credentials": {
     "examples": [
       false
     ],
     "type": [
       "boolean",
       "null"
     ]
   },
   "oauth_window_uri": {
     "examples": [
       "https://mxbank.mx.com/oauth/authorize?client_id=b8OikQ4Ep3NuSUrQ13DdvFuwpNx-qqoAsJDVAQCyLkQ&redirect_uri=https%3A%2F%2Fint-app.moneydesktop.com%2Foauth%2Fredirect_from&response_type=code&scope=openid&state=d745bd4ee6f0f9c184757f574bcc2df2"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "successfully_aggregated_at": {
     "examples": [
       "2016-10-13T17:57:38.000Z"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "use_cases": {
     "description": "The use case associated with the member. Valid
values are `PFM` and/or `MONEY_MOVEMENT`. Only set this if you've met
with MX and have opted in to using this field.",
     "examples": [
       [
         "PFM"
       ]
     ],
     "type": "array",
     "items": {
       "type": "string",
       "enum": [
         "MONEY_MOVEMENT",
         "PFM"
       ]
     }
   },
   "user_guid": {
     "examples": [
       "USR-fa7537f3-48aa-a683-a02a-b18940482f54"
     ],
     "type": [
       "string",
       "null"
     ]
   },
   "user_id": {
     "examples": [
       "user123"
     ],
     "type": [
       "string",
       "null"
     ]
   }
 }
}

Fields

aggregated_at: Option<String>background_aggregation_is_disabled: Option<bool>connection_status: Option<String>connection_status_message: Option<String>guid: Option<String>id: Option<String>institution_code: Option<String>institution_guid: Option<String>is_being_aggregated: Option<bool>is_managed_by_user: Option<bool>is_manual: Option<bool>is_oauth: Option<bool>metadata: Option<String>most_recent_job_detail_code: Option<i64>most_recent_job_detail_text: Option<bool>most_recent_job_guid: Option<bool>name: Option<String>needs_updated_credentials: Option<bool>oauth_window_uri: Option<String>successfully_aggregated_at: Option<String>use_cases: Vec<MemberResponseUseCasesItem>

The use case associated with the member. Valid values are PFM and/or MONEY_MOVEMENT. Only set this if you’ve met with MX and have opted in to using this field.

user_guid: Option<String>user_id: Option<String>