pub struct MonthlyCashFlowResponse {
pub budgeted_expenses: Option<f64>,
pub budgeted_income: Option<f64>,
pub estimated_goals_contribution: Option<f64>,
pub goals_contribution: Option<f64>,
pub guid: Option<String>,
pub user_guid: Option<String>,
pub uses_estimated_goals_contribution: Option<bool>,
}Expand description
MonthlyCashFlowResponse
JSON schema
{
"properties": {
"budgeted_expenses": {
"description": "The amount of the budgeted expenses for the user.",
"examples": [
1000
],
"type": "number"
},
"budgeted_income": {
"description": "The amount of the budgeted income for the user.",
"examples": [
1200.12
],
"type": "number"
},
"estimated_goals_contribution": {
"description": "The estimated monthly dollar amount allocated for
goals calculated from income and budgets.",
"type": [
"number",
"null"
]
},
"goals_contribution": {
"description": "The monthly dollar amount allocated for goals.",
"examples": [
150
],
"type": "number"
},
"guid": {
"description": "Unique identifier for the monthly cash flow
profile. Defined by MX.",
"examples": [
"MCF-4e431124-4a29-abf9-f059-ab232ac14dbf"
],
"type": "string"
},
"user_guid": {
"description": "Unique identifier for the user the monthly cash
flow profile is attached to. Defined by MX.",
"examples": [
"USR-6c83f63c-efcc-0189-3f14-100f0bad378a"
],
"type": "string"
},
"uses_estimated_goals_contribution": {
"examples": [
false
],
"type": "boolean"
}
}
}Fields
budgeted_expenses: Option<f64>budgeted_income: Option<f64>estimated_goals_contribution: Option<f64>The estimated monthly dollar amount allocated for goals calculated from income and budgets.
goals_contribution: Option<f64>guid: Option<String>Unique identifier for the monthly cash flow profile. Defined by MX.
user_guid: Option<String>Unique identifier for the user the monthly cash flow profile is attached to. Defined by MX.
uses_estimated_goals_contribution: Option<bool>Trait Implementations
Sourceimpl Clone for MonthlyCashFlowResponse
impl Clone for MonthlyCashFlowResponse
Sourcefn clone(&self) -> MonthlyCashFlowResponse
fn clone(&self) -> MonthlyCashFlowResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonthlyCashFlowResponse
impl Debug for MonthlyCashFlowResponse
Sourceimpl Default for MonthlyCashFlowResponse
impl Default for MonthlyCashFlowResponse
Sourceimpl<'de> Deserialize<'de> for MonthlyCashFlowResponse
impl<'de> Deserialize<'de> for MonthlyCashFlowResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&MonthlyCashFlowResponse> for MonthlyCashFlowResponse
impl From<&MonthlyCashFlowResponse> for MonthlyCashFlowResponse
Sourcefn from(value: &MonthlyCashFlowResponse) -> Self
fn from(value: &MonthlyCashFlowResponse) -> Self
Converts to this type from the input type.