pub struct RepositionRequest {
pub guid: String,
pub position: i64,
}Expand description
RepositionRequest
JSON schema
{
"required": [
"guid",
"position"
],
"properties": {
"guid": {
"description": "The unique identifier for the goal. Defined by
MX.",
"examples": [
"GOL-97665947-235c-b213-ca25-8cf0174774f5"
],
"type": "string"
},
"position": {
"description": "The priority of the goal in relation to multiple
goals.",
"examples": [
1
],
"type": "integer"
}
}
}Fields
guid: StringThe unique identifier for the goal. Defined by MX.
position: i64The priority of the goal in relation to multiple goals.