pub struct TransactionCreateRequest {
pub amount: f64,
pub category_guid: Option<String>,
pub currency_code: Option<String>,
pub date: String,
pub description: String,
pub has_been_viewed: Option<bool>,
pub is_hidden: Option<bool>,
pub is_international: Option<bool>,
pub memo: Option<String>,
pub metadata: Option<String>,
pub skip_webhook: Option<bool>,
pub type_: String,
}Expand description
TransactionCreateRequest
JSON schema
{
"required": [
"amount",
"date",
"description",
"type"
],
"properties": {
"amount": {
"examples": [
61.11
],
"type": "number"
},
"category_guid": {
"description": "Unique identifier of the category.",
"examples": [
"CAT-b6d61a19-30a7-e852-2703-bdfb4072289e"
],
"type": "string"
},
"currency_code": {
"examples": [
"USD"
],
"type": "string"
},
"date": {
"examples": [
"2016-10-06"
],
"type": "string"
},
"description": {
"examples": [
"Whole foods"
],
"type": "string"
},
"has_been_viewed": {
"examples": [
false
],
"type": "boolean"
},
"is_hidden": {
"examples": [
false
],
"type": "boolean"
},
"is_international": {
"examples": [
false
],
"type": "boolean"
},
"memo": {
"examples": [
"This is a memo"
],
"type": "string"
},
"metadata": {
"examples": [
"some metadata"
],
"type": "string"
},
"skip_webhook": {
"description": "When set to true, this parameter will prevent a
webhook from being triggered by the request.",
"examples": [
true
],
"type": "boolean"
},
"type": {
"description": "The type of transaction, which must be CREDIT or
DEBIT. See Transaction Fields for more information.",
"examples": [
"DEBIT"
],
"type": "string"
}
}
}Fields
amount: f64category_guid: Option<String>Unique identifier of the category.
currency_code: Option<String>date: Stringdescription: Stringhas_been_viewed: Option<bool>is_international: Option<bool>memo: Option<String>metadata: Option<String>skip_webhook: Option<bool>When set to true, this parameter will prevent a webhook from being triggered by the request.
type_: StringThe type of transaction, which must be CREDIT or DEBIT. See Transaction Fields for more information.