pub struct WidgetRequest {Show 22 fields
pub client_redirect_url: Option<String>,
pub color_scheme: Option<String>,
pub connections_use_case_filter: Option<bool>,
pub current_institution_code: Option<String>,
pub current_institution_guid: Option<String>,
pub current_member_guid: Option<String>,
pub disable_background_agg: Option<bool>,
pub disable_institution_search: Option<bool>,
pub enable_app2app: Option<bool>,
pub include_identity: Option<bool>,
pub include_transactions: Option<bool>,
pub insight_guid: Option<String>,
pub is_mobile_webview: Option<bool>,
pub iso_country_code: Vec<String>,
pub microwidget_instance_id: Option<String>,
pub mode: Option<String>,
pub oauth_referral_source: Option<String>,
pub ui_message_version: Option<i64>,
pub ui_message_webview_url_scheme: Option<String>,
pub update_credentials: Option<bool>,
pub use_cases: Vec<WidgetRequestUseCasesItem>,
pub widget_type: String,
}Expand description
WidgetRequest
JSON schema
{
"type": "object",
"required": [
"widget_type"
],
"properties": {
"client_redirect_url": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This determines the redirect destination at the end of
OAuth when used with `is_mobile_webview: true` or
`oauth_referral_source: 'APP'`.\n",
"examples": [
"https://{yoursite.com}"
],
"type": "string"
},
"color_scheme": {
"description": "This option can be passed to any `widget_type` but will not affect [legacy PFM widgets](products/experience/pfm/legacy-widget-overviews/). Load the widget with the specified `color_scheme`; options are `light`, `browser` (respects user's browser setting), and `dark`. Defaults to `light`.",
"examples": [
"light"
],
"type": "string"
},
"connections_use_case_filter": {
"description": "To use this parameter, you must also set
`use_cases` in the same request. If `connections_use_case_filter` is set
to `true`, the Connections Widget will only show connections (members)
with the `use_cases` you set in the same request. For some examples, see
[Filter Connections](/products/experience/pfm/widget-overviews/
connections-widget#example-1).",
"examples": [
false
],
"type": "boolean"
},
"current_institution_code": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. Load the widget into the credential view for the
specified institution.\n",
"examples": [
"mxbank"
],
"type": "string"
},
"current_institution_guid": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. Load the widget into the credential view for the
specified institution.\n",
"examples": [
"INS-f1a3285d-e855-b61f-6aa7-8ae575c0e0e9"
],
"type": "string"
},
"current_member_guid": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. Load the widget into a specific member that contains
an error or requires multifactor authentication. The widget will
determine the best view to load based on the member's current state.
`current_member_guid` takes precedence over `current_institution_code`
and `current_institution_guid`.\n",
"examples": [
"MBR-7c6f361b-e582-15b6-60c0-358f12466b4b"
],
"type": "string"
},
"disable_background_agg": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This determines whether background aggregation is
enabled or disabled for the member created by the Connect Widget.
Defaults to `false` in `aggregation` mode and `true` in `verification`
mode. A global default for all members can be set by reaching out to
MX.\n",
"examples": [
false
],
"type": "boolean"
},
"disable_institution_search": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This determines whether the institution search is
displayed within the Connect Widget. This option must be used with
`current_institution_code`, `current_instituion_guid`, or
`current_member_guid`. When set to `true`, the institution search
feature will be disabled and end users will not be able to navigate to
it. Defaults to `false`.\n",
"examples": [
false
],
"type": "boolean"
},
"enable_app2app": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This indicates whether OAuth app2app behavior is
enabled for institutions that support it. Defaults to `true`. When set
to `false`, the widget will **not** direct the end user to the
institution's mobile application. This setting is not persistent. This
setting currently only affects Chase institutions.\n",
"examples": [
false
],
"type": "boolean"
},
"include_identity": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This determines whether an account owner
identification (AOI, previously called identity verification) is run in
addition to the process specified by the `mode`. Defaults to `false`.
This can be set in either `aggregation` or `verification` mode. The AOI
runs after the primary process is complete.\n",
"examples": [
false
],
"type": "boolean"
},
"include_transactions": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This determines whether transaction data are
retrieved. Defaults to `true` in aggregation mode and `false` in
verification mode. This can be set in either `aggregation` or
`verification` mode. This option does not affect future foreground or
background aggregations.\n",
"examples": [
true
],
"type": "boolean"
},
"insight_guid": {
"description": "Only use this option if the `widget_type` is set to
`pulse_widget`. Set this to the insight guid you want to appear at the
top of the insights feed.\n",
"type": [
"string",
"null"
]
},
"is_mobile_webview": {
"description": "This option is for all `widget_type`s. This
configures the widget to render in a mobile WebView. JavaScript event
postMessages are replaced with URL updates.\n",
"examples": [
false
],
"type": "boolean"
},
"iso_country_code": {
"description": "An array of strings that filters institutions in
the widget by the specified country code. Acceptable codes include `US`,
`CA`, and `MX` (Mexico).\n",
"examples": [
[
"US",
"CA"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"microwidget_instance_id": {
"description": "Only use this option if the `widget_type` is set to
`micro_pulse_carousel_widget`. Set this to a unique value for each
instance of the Micro Widget. This lets us collect unique data for each
instance of the widget.\n",
"type": [
"string",
"null"
]
},
"mode": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. `mode` is the most important option for the Connect
Widget. This determines what kind of process Connect will run, which
affects how you should set many other options. Defaults to
`aggregation`. `aggregation` mode retrieves account and transaction
data; in other words, this runs a standard aggregation. `verification`
mode retrieves account numbers and routing/transit numbers; in other
words, it runs an Instant Account Verification (IAV). By default,
verification mode does not retrieve transaction data; this default can
be modified with secondary options. By default, background aggregation
is disabled for all members created in verification mode; this default
can be modified with secondary options.\n",
"examples": [
"aggregation"
],
"type": "string"
},
"oauth_referral_source": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This determines how MX will respond to the result of
an OAuth flow. When set to `APP`, MX will redirect to the URI specified
in the `ui_message_webview_url_scheme`. When set to `BROWSER`, MX will
send a postMessage but not redirect. If `is_mobile_webview` is `true`,
this defaults to `APP`. If false, it defaults to `BROWSER`.\n",
"examples": [
"BROWSER"
],
"type": "string"
},
"ui_message_version": {
"description": "This option is for all `widget_type`s. This
determines which version of postMessage events are triggered. Defaults
to 4. All new implementations must use version 4. Prior versions are
deprecated.\n",
"examples": [
4
],
"type": "integer"
},
"ui_message_webview_url_scheme": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. This is a client-defined scheme used in OAuth
redirects in WebViews; also used in URL updates when these replace
postMessages in WebViews. Defaults to `mx`.\n",
"type": "string"
},
"update_credentials": {
"description": "Only use this option if the `widget_type` is set to
`connect_widget`. Load the widget into a view that allows them to update
the current member. Optionally used with `current_member_guid`. This
option should be used sparingly. The best practice is to use
`current_member_guid` and let the widget resolve the issue.\n",
"examples": [
false
],
"type": "boolean"
},
"use_cases": {
"description": "The use case that will be associated with any
members created through the widget. Valid values are `PFM` and/or
`MONEY_MOVEMENT`. This is **required** if you've met with MX, opted in
to using this field, and are requesting a widget with a `widget_type` of
`connect_widget` or `connections_widget`.",
"examples": [
[
"PFM"
]
],
"type": "array",
"items": {
"type": "string",
"enum": [
"MONEY_MOVEMENT",
"PFM"
]
}
},
"widget_type": {
"description": "This determines which widget URL you'll
receive.\n\nSee [Widget
Types](/api-reference/platform-api/reference/widget-types) for a list of
potential values. Additional request parameters may only apply to some
widget types.\n",
"examples": [
"connect_widget"
],
"type": "string"
}
}
}Fields
client_redirect_url: Option<String>Only use this option if the widget_type is set to
connect_widget. This determines the redirect destination at the
end of OAuth when used with is_mobile_webview: true or
oauth_referral_source: 'APP'.
color_scheme: Option<String>This option can be passed to any widget_type but will not affect
legacy PFM
widgets. Load the
widget with the specified color_scheme; options are light,
browser (respects user’s browser setting), and dark. Defaults to
light.
connections_use_case_filter: Option<bool>To use this parameter, you must also set use_cases in the same
request. If connections_use_case_filter is set to true, the
Connections Widget will only show connections (members) with the
use_cases you set in the same request. For some examples, see
[Filter Connections](/products/experience/pfm/widget-overviews/
connections-widget#example-1).
current_institution_code: Option<String>Only use this option if the widget_type is set to
connect_widget. Load the widget into the credential view for the
specified institution.
current_institution_guid: Option<String>Only use this option if the widget_type is set to
connect_widget. Load the widget into the credential view for the
specified institution.
current_member_guid: Option<String>Only use this option if the widget_type is set to
connect_widget. Load the widget into a specific member that
contains an error or requires multifactor authentication. The widget
will determine the best view to load based on the member’s current
state. current_member_guid takes precedence over
current_institution_code and current_institution_guid.
disable_background_agg: Option<bool>Only use this option if the widget_type is set to
connect_widget. This determines whether background aggregation is
enabled or disabled for the member created by the Connect Widget.
Defaults to false in aggregation mode and true in
verification mode. A global default for all members can be set by
reaching out to MX.
disable_institution_search: Option<bool>Only use this option if the widget_type is set to
connect_widget. This determines whether the institution search is
displayed within the Connect Widget. This option must be used with
current_institution_code, current_instituion_guid, or
current_member_guid. When set to true, the institution search
feature will be disabled and end users will not be able to navigate
to it. Defaults to false.
enable_app2app: Option<bool>Only use this option if the widget_type is set to
connect_widget. This indicates whether OAuth app2app behavior is
enabled for institutions that support it. Defaults to true. When
set to false, the widget will not direct the end user to the
institution’s mobile application. This setting is not persistent.
This setting currently only affects Chase institutions.
include_identity: Option<bool>Only use this option if the widget_type is set to
connect_widget. This determines whether an account owner
identification (AOI, previously called identity verification) is run
in addition to the process specified by the mode. Defaults to
false. This can be set in either aggregation or verification
mode. The AOI runs after the primary process is complete.
include_transactions: Option<bool>Only use this option if the widget_type is set to
connect_widget. This determines whether transaction data are
retrieved. Defaults to true in aggregation mode and false in
verification mode. This can be set in either aggregation or
verification mode. This option does not affect future foreground
or background aggregations.
insight_guid: Option<String>Only use this option if the widget_type is set to pulse_widget.
Set this to the insight guid you want to appear at the top of the
insights feed.
is_mobile_webview: Option<bool>This option is for all widget_types. This configures the widget to
render in a mobile WebView. JavaScript event postMessages are
replaced with URL updates.
iso_country_code: Vec<String>An array of strings that filters institutions in the widget by the
specified country code. Acceptable codes include US, CA, and
MX (Mexico).
microwidget_instance_id: Option<String>Only use this option if the widget_type is set to
micro_pulse_carousel_widget. Set this to a unique value for each
instance of the Micro Widget. This lets us collect unique data for
each instance of the widget.
mode: Option<String>Only use this option if the widget_type is set to
connect_widget. mode is the most important option for the
Connect Widget. This determines what kind of process Connect will
run, which affects how you should set many other options. Defaults
to aggregation. aggregation mode retrieves account and
transaction data; in other words, this runs a standard aggregation.
verification mode retrieves account numbers and routing/transit
numbers; in other words, it runs an Instant Account Verification
(IAV). By default, verification mode does not retrieve transaction
data; this default can be modified with secondary options. By
default, background aggregation is disabled for all members created
in verification mode; this default can be modified with secondary
options.
oauth_referral_source: Option<String>Only use this option if the widget_type is set to
connect_widget. This determines how MX will respond to the result
of an OAuth flow. When set to APP, MX will redirect to the URI
specified in the ui_message_webview_url_scheme. When set to
BROWSER, MX will send a postMessage but not redirect. If
is_mobile_webview is true, this defaults to APP. If false, it
defaults to BROWSER.
ui_message_version: Option<i64>This option is for all widget_types. This determines which version
of postMessage events are triggered. Defaults to 4. All new
implementations must use version 4. Prior versions are deprecated.
ui_message_webview_url_scheme: Option<String>Only use this option if the widget_type is set to
connect_widget. This is a client-defined scheme used in OAuth
redirects in WebViews; also used in URL updates when these replace
postMessages in WebViews. Defaults to mx.
update_credentials: Option<bool>Only use this option if the widget_type is set to
connect_widget. Load the widget into a view that allows them to
update the current member. Optionally used with
current_member_guid. This option should be used sparingly. The
best practice is to use current_member_guid and let the widget
resolve the issue.
use_cases: Vec<WidgetRequestUseCasesItem>The use case that will be associated with any members created
through the widget. Valid values are PFM and/or MONEY_MOVEMENT.
This is required if you’ve met with MX, opted in to using this
field, and are requesting a widget with a widget_type of
connect_widget or connections_widget.
widget_type: StringThis determines which widget URL you’ll receive.
See Widget Types for a list of potential values. Additional request parameters may only apply to some widget types.